@@ -21,12 +21,10 @@ import signal
 import time
 import typing
 
-from airflow.contrib.executors.kubernetes_executor import (
-    AirflowKubernetesScheduler,
-    KubeConfig,
-    KubernetesExecutor,
-    KubernetesJobWatcher,
-)
+from distutils.version import LooseVersion
+
+import airflow
+
 from airflow.models import KubeWorkerIdentifier
 from airflow.utils.db import provide_session
 from airflow.utils.state import State
@@ -35,6 +33,15 @@ from dbnd._core.constants import TaskRunState
 from dbnd._core.current import try_get_databand_run
 from dbnd._core.errors.base import DatabandRuntimeError, DatabandSigTermError
 from dbnd._core.utils.basics.signal_utils import safe_signal
+from dbnd_airflow.compat.kubernetes_executor import (
+    AirflowKubernetesScheduler,
+    KubeConfig,
+    KubernetesExecutor,
+    KubernetesJobWatcher,
+    get_job_watcher_kwargs,
+    get_tuple_for_watcher_queue,
+    make_safe_label_value,
+)
 from dbnd_airflow_contrib.kubernetes_metrics_logger import KubernetesMetricsLogger
 from dbnd_docker.kubernetes.kube_dbnd_client import (
     DbndKubernetesClient,
@@ -93,7 +100,7 @@ def _update_airflow_kube_config(airflow_kube_config, engine_config):
         airflow_kube_config.kube_image_pull_policy = ec.image_pull_policy
     if ec.node_selectors is not None:
         airflow_kube_config.kube_node_selectors.update(ec.node_selectors)
-    if ec.annotations is not None:
+    if ec.annotations is not None and airflow_kube_config.kube_annotations is not None:
         airflow_kube_config.kube_annotations.update(ec.annotations)
 
     if ec.pods_creation_batch_size is not None:
@@ -156,14 +163,7 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
         return None
 
     def _make_kube_watcher_dbnd(self):
-        watcher = DbndKubernetesJobWatcher(
-            namespace=self.namespace,
-            watcher_queue=self.watcher_queue,
-            resource_version=self.current_resource_version,
-            worker_uuid=self.worker_uuid,
-            kube_config=self.kube_config,
-            kube_dbnd=self.kube_dbnd,
-        )
+        watcher = DbndKubernetesJobWatcher(**get_job_watcher_kwargs(self))
         watcher.start()
         return watcher
 
@@ -207,8 +207,8 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
             cmds=pod_command,
             labels={
                 "airflow-worker": self.worker_uuid,
-                "dag_id": self._make_safe_label_value(dag_id),
-                "task_id": self._make_safe_label_value(task_run.task_af_id),
+                "dag_id": make_safe_label_value(dag_id),
+                "task_id": make_safe_label_value(task_run.task_af_id),
                 "execution_date": self._datetime_to_label_safe_datestring(
                     execution_date
                 ),
@@ -225,7 +225,10 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
         pod_ctrl.run_pod(pod=pod, task_run=task_run, detach_run=True)
         self.metrics_logger.log_pod_started(task_run.task)
 
-    def delete_pod(self, pod_id):
+    # in airflow>1.10.10 delete_pod method takes additional "namespace" arg
+    # we do not use it in our overridden method but still we need to adjust
+    # method signature to avoid errors when we run code on airflow>1.10.10.
+    def delete_pod(self, pod_id, *args):
         if pod_id in self.failed_pods_to_ignore:
             logger.warning(
                 "Received request to delete pod %s that is ignored! Ignoring...", pod_id
@@ -532,10 +535,18 @@ class DbndKubernetesJobWatcher(KubernetesJobWatcher):
             self.log.debug("Event: %s Pending", pod_id)
         elif status == "Failed":
             self.log.debug("Event: %s Failed", pod_id)
-            self.watcher_queue.put((pod_id, State.FAILED, labels, resource_version))
+            self.watcher_queue.put(
+                get_tuple_for_watcher_queue(
+                    pod_id, self.namespace, State.FAILED, labels, resource_version
+                )
+            )
         elif status == "Succeeded":
             self.log.debug("Event: %s Succeeded", pod_id)
-            self.watcher_queue.put((pod_id, State.SUCCESS, labels, resource_version))
+            self.watcher_queue.put(
+                get_tuple_for_watcher_queue(
+                    pod_id, self.namespace, State.SUCCESS, labels, resource_version
+                )
+            )
         elif status == "Running":
             self.log.debug("Event: %s is Running", pod_id)
         else:
