@@ -14,6 +14,7 @@ from airflow.utils.state import State
 from sqlalchemy import and_, or_
 from sqlalchemy.orm.session import make_transient
 
+from databand import dbnd_config
 from dbnd._core import current
 from dbnd._core.constants import TaskRunState
 from dbnd._core.current import get_databand_run
@@ -724,6 +725,10 @@ class SingleDagRunJob(BaseJob, SingletonContext):
         Initializes all components required to run a dag for a specified date range and
         calls helper method to execute the tasks.
         """
+        # Trigger cleaning
+        if self.airflow_config.clean_zombies_during_backfill:
+            ClearZombieJob().run()
+
         ti_status = BackfillJob._DagRunTaskStatus()
 
         # picklin'
@@ -813,7 +818,7 @@ def find_and_kill_zombies(args, session=None):
     Find zombie DagRuns and TaskInstances that are in not end state and for which related
     BackfillJob has failed.
     """
-    seconds_from_last_heartbeat = 30
+    seconds_from_last_heartbeat = 60
     last_expected_heartbeat = timezone.utcnow() - datetime.timedelta(
         seconds=seconds_from_last_heartbeat
     )
@@ -839,7 +844,7 @@ def find_and_kill_zombies(args, session=None):
     )
     failed_jobs_id = set(r[0] for r in failed_jobs_id_qry)
 
-    logger.info("Found %s failed jobs", len(failed_jobs_id))
+    logger.info("Found %s stale jobs", len(failed_jobs_id))
 
     running_dag_runs = session.query(DagRun).filter(DagRun.state == State.RUNNING).all()
 
@@ -860,3 +865,38 @@ def find_and_kill_zombies(args, session=None):
         _kill_zombies(dag_run=dr, session=session)
 
     logger.info("Cleaning done!")
+
+
+class ClearZombieJob(BaseJob):
+    ID_PREFIX = BackfillJob.ID_PREFIX + "manual_    "
+    ID_FORMAT_PREFIX = ID_PREFIX + "{0}"
+    __mapper_args__ = {"polymorphic_identity": "BackfillJob"}
+    TYPE = "ZombieJob"
+    TIME_BETWEEN_RUNS = 60 * 5
+
+    def __init__(self, *args, **kwargs):
+        super(ClearZombieJob, self).__init__(*args, **kwargs)
+        # Trick for distinguishing this job from other backfills
+        self.executor_class = self.TYPE
+
+    @provide_session
+    def _execute(self, session=None):
+        last_run_date = (
+            session.query(ClearZombieJob.latest_heartbeat)
+            .filter(ClearZombieJob.executor_class == self.TYPE)
+            .order_by(ClearZombieJob.end_date.asc())
+            .first()
+        )
+        if (
+            last_run_date
+            and last_run_date[0] + datetime.timedelta(seconds=self.TIME_BETWEEN_RUNS)
+            > timezone.utcnow()
+        ):
+            # If we cleaned zombies recently we can do nothing
+            return
+        try:
+            find_and_kill_zombies(None, session=session)
+        except Exception as err:
+            # Fail silently as this is not crucial process
+            session.rollback()
+            logging.warning("Cleaning zombies failed: %s", err)
